Package: serosv
Type: Package
Title: Model Infectious Disease Parameters from Serosurveys
Version: 1.3.0
Authors@R: c(
    person("Anh", "Phan Truong Quynh", email = "anhptq@oucru.org", role = c("aut", "cre"), comment = c(ORCID = "0009-0000-2129-435X")),
    person("Nguyen", "Pham Nguyen The", email = "nguyenpnt@oucru.org", role = c("aut"), comment = c(ORCID = "0000-0002-0356-2776")),
    person("Long", "Bui Thanh", role = "aut"),
    person("Tuyen", "Huynh", email = "tuyenhn@oucru.org", role = "aut"),
    person("Thinh", "Ong", email = "thinhop@oucru.org", role = "aut", comment = c(ORCID = "0000-0001-6772-9291")),
    person("Marc", "Choisy", email = "mchoisy@oucru.org", role = "aut", comment = c(ORCID = "0000-0002-5187-6390"))
  )
Description: An easy-to-use and efficient tool to estimate infectious diseases parameters using serological data. Implemented models include SIR models (basic_sir_model(), static_sir_model(), mseir_model(), sir_subpops_model()), parametric models (polynomial_model(), fp_model()), nonparametric models (lp_model()), semiparametric models (penalized_splines_model()), hierarchical models (hierarchical_bayesian_model()).
  The package is based on the book "Modeling Infectious Disease Parameters Based on Serological and Social Contact Data: A Modern Statistical Perspective" (Hens, Niel & Shkedy, Ziv & Aerts, Marc & Faes, Christel & Damme, Pierre & Beutels, Philippe., 2013) <doi:10.1007/978-1-4614-4072-7>. 
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.1.0)
RoxygenNote: 7.3.3
Imports: dplyr, tidyr, janitor, ggplot2, locfit, purrr, stringr,
        magrittr, methods, mgcv, mixdist, scam, mvtnorm, patchwork,
        assertthat, Rcpp (>= 0.12.0), RcppParallel (>= 5.0.1), rstan
        (>= 2.18.1), rstantools (>= 2.4.0), boot, pROC, stats4, rlang
        (>= 1.1.0)
Suggests: covr, knitr, rmarkdown, bookdown, testthat (>= 3.0.0)
Collate: 'data.R' 'fractional_polynomial_models.R'
        'polynomial_models.R' 'utils.R' 'compare_models.R'
        'correct_prevalence.R' 'weibull_model.R' 'farrington_model.R'
        'nonparametric.R' 'semiparametric_models.R' 'mixture_model.R'
        'hierarchical_bayesian_model.R' 'to_titer.R' 'serosv.R'
        'stanmodels.R' 'plots.R' 'compute_ci.R' 'age_time_model.R'
        'predict.R' 'print.R'
Config/testthat/edition: 3
URL: https://oucru-modelling.github.io/serosv/,
        https://github.com/OUCRU-Modelling/serosv
VignetteBuilder: knitr
Biarch: true
LinkingTo: BH (>= 1.66.0), Rcpp (>= 0.12.0), RcppEigen (>= 0.3.3.3.0),
        RcppParallel (>= 5.0.1), rstan (>= 2.18.1), StanHeaders (>=
        2.18.0)
SystemRequirements: GNU make
BugReports: https://github.com/OUCRU-Modelling/serosv/issues
NeedsCompilation: yes
Packaged: 2026-04-07 12:44:58 UTC; anhptq
Author: Anh Phan Truong Quynh [aut, cre] (ORCID:
    <https://orcid.org/0009-0000-2129-435X>),
  Nguyen Pham Nguyen The [aut] (ORCID:
    <https://orcid.org/0000-0002-0356-2776>),
  Long Bui Thanh [aut],
  Tuyen Huynh [aut],
  Thinh Ong [aut] (ORCID: <https://orcid.org/0000-0001-6772-9291>),
  Marc Choisy [aut] (ORCID: <https://orcid.org/0000-0002-5187-6390>)
Maintainer: Anh Phan Truong Quynh <anhptq@oucru.org>
Repository: CRAN
Date/Publication: 2026-04-07 13:20:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-04-08 02:36:51 UTC; unix
Archs: serosv.so.dSYM
