# Generated by roxygen2: do not edit by hand

S3method(compute_ci,age_time_model)
S3method(compute_ci,default)
S3method(compute_ci,fp_model)
S3method(compute_ci,hierarchical_bayesian_model)
S3method(compute_ci,lp_model)
S3method(compute_ci,mixture_model)
S3method(compute_ci,penalized_spline_model)
S3method(compute_ci,weibull_model)
S3method(plot,age_time_model)
S3method(plot,estimate_from_mixture)
S3method(plot,farrington_model)
S3method(plot,fp_model)
S3method(plot,hierarchical_bayesian_model)
S3method(plot,lp_model)
S3method(plot,mixture_model)
S3method(plot,penalized_spline_model)
S3method(plot,polynomial_model)
S3method(plot,weibull_model)
S3method(predict,age_time_model)
S3method(predict,farrington_model)
S3method(predict,fp_model)
S3method(predict,hierarchical_bayesian_model)
S3method(predict,lp_model)
S3method(predict,penalized_spline_model)
S3method(predict,polynomial_model)
S3method(predict,weibull_model)
S3method(print,age_time_model)
S3method(print,estimate_from_mixture)
S3method(print,farrington_model)
S3method(print,fp_model)
S3method(print,hierarchical_bayesian_model)
S3method(print,lp_model)
S3method(print,mixture_model)
S3method(print,penalized_spline_model)
S3method(print,polynomial_model)
S3method(print,weibull_model)
export(add_thresholds)
export(age_time_model)
export(compare_models)
export(correct_prevalence)
export(est_foi)
export(estimate_from_mixture)
export(farrington_model)
export(fp_model)
export(hierarchical_bayesian_model)
export(lp_model)
export(mixture_model)
export(pava)
export(penalized_spline_model)
export(plot_corrected_prev)
export(plot_gcv)
export(plot_standard_curve)
export(plot_titer_qc)
export(polynomial_model)
export(set_plot_style)
export(standardize_data)
export(to_titer)
export(transform_data)
export(weibull_model)
import(Rcpp)
import(assertthat)
import(dplyr)
import(ggplot2)
import(graphics)
import(locfit)
import(methods)
import(pROC)
import(patchwork)
import(scam)
import(tidyr)
importFrom(RcppParallel,RcppParallelLibs)
importFrom(assertthat,assert_that)
importFrom(boot,inv.logit)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,summarize)
importFrom(grDevices,adjustcolor)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(janitor,clean_names)
importFrom(locfit,"crit<-")
importFrom(locfit,crit)
importFrom(locfit,gcv)
importFrom(locfit,gcvplot)
importFrom(locfit,locfit)
importFrom(locfit,lp)
importFrom(magrittr,"%>%")
importFrom(methods,is)
importFrom(mgcv,betar)
importFrom(mgcv,gam)
importFrom(mgcv,gamm)
importFrom(mgcv,predict.gam)
importFrom(mixdist,mix)
importFrom(mixdist,mixgroup)
importFrom(mixdist,mixparam)
importFrom(mvtnorm,rmvnorm)
importFrom(purrr,as_mapper)
importFrom(purrr,compact)
importFrom(purrr,imap_dfr)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map_dbl)
importFrom(purrr,map_dfc)
importFrom(purrr,map_dfr)
importFrom(purrr,pmap)
importFrom(purrr,pmap_dfr)
importFrom(purrr,walk)
importFrom(rlang,`:=`)
importFrom(rstan,sampling)
importFrom(rstan,summary)
importFrom(rstantools,rstan_config)
importFrom(stats,anova)
importFrom(stats,approx)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,dbinom)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,gaussian)
importFrom(stats,glm)
importFrom(stats,median)
importFrom(stats,nls)
importFrom(stats,predict)
importFrom(stats,predict.glm)
importFrom(stats,prop.test)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(stats,vcov)
importFrom(stats4,AIC)
importFrom(stats4,BIC)
importFrom(stats4,logLik)
importFrom(stats4,mle)
importFrom(stringr,str_detect)
importFrom(utils,head)
useDynLib(serosv, .registration=TRUE)
